cheesecake.model

Package cheesecake :: Module model |
[show private | hide private]
[frames | no frames]

## Module cheesecake.model

Code borrowed from Michael Hudson's docextractor package with the author's permission.

The original code is available at http://codespeak.net/svn/user/mwh/docextractor/.

Changes:
  - do not print warnings to stdout (in System.warning)
  - collect all function calls

Classes
`Class` |
`Documentable` |
`Function` |
`ImportStarFinder` |
`Module` |
`ModuleVistor` |
`Package` |
`System` |

Function Summary
| `expandModname(system, modname, givewarning)`
| `extractDocstrings(system)`
| `finalStateComputations(system)`
| `findImportStars(system)`
| `fromText(src, modname, system)`
| `get_call_name(node)`
| `get_function_calls(node, fc)`
| `main(systemcls, argv)`
| `preprocessDirectory(system, dirpath)`
| `processDirectory(system, dirpath)`
| `processModuleAst(ast, name, system)`
| `toposort(input, edges)`

Variable Summary
`list` | `states` = `['blank', 'preparse', 'importstarred', 'parsed'...`

Variable Details

    ### states Type: `list` Value:
        ['blank', 'preparse', 'importstarred', 'parsed', 'finalized']

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net